@@ -1,4 +1,4 @@
-"""usage: task query [options] [<query>...]
+"""Usage: task query [options] [<query>...]
 
 Search or list tasks in this list.
 
@@ -12,7 +12,7 @@ or by visiting:
 
 http://taskforge.io/docs/query_language
 
-options:
+Options:
     -o <format>, --output <format>  How to display the tasks which match the
                                     query. Available formats are: json, csv,
                                     table, text which are described below.
@@ -146,7 +146,6 @@ def print_tasks(tasks, output='table'):
 @inject_list
 def query_tasks(query, task_list=None):
     """Return tasks which match query or all tasks if query is blank"""
-    print([t for t in task_list.conn.execute('select * from tasks')])
     if query:
         ast = Parser(query).parse()
         return task_list.search(ast)
