@@ -1,4 +1,4 @@
-"""usage: task workon <ID>
+"""Usage: task workon <ID>
 
 Find task with ID and make it so the priority of the task is 0.1 higher than
 that of the current highest priority task. Effectively making it the "current"
